# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os
import logging
from time import sleep
import subprocess
import zc.buildout
import zc.buildout.easy_install
import zc.recipe.egg

class Recipe(object):
  def __init__(self, buildout, name, options):
    self.buildout, self.options, self.name = buildout, options, name
    self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
    self.logger=logging.getLogger(self.name)

    options['location'] = os.path.join(
        buildout['buildout']['parts-directory'],
        self.name)

    options.setdefault('mysql_bin_folder',
                       buildout['buildout']['bin-directory'])

    options.setdefault("mysql_auto_start", "false")


  def install_script(self, script_name):
    """ Create default scripts
    """
    options = self.options
    mysql_software_bin = options.get("mysql_software_bin")
    mysql_cnf_file = options.get("mysql_cnf_file")
    requirements, ws = self.egg.working_set(['erp5.recipe.mysqlserver'])
    scripts = zc.buildout.easy_install.scripts(
        [(script_name,'erp5.recipe.mysqlserver.ctl', 'main')],
        ws, options['executable'], options.get("mysql_bin_folder"),
        arguments = ("\n        ['%s/%s' ,"
                     "\n        '--defaults-file=%s'] "
                     "\n        + sys.argv[1:]" % (mysql_software_bin,
                                                   script_name,
                                                   mysql_cnf_file)))

  def install(self):
    options = self.options
    location = options['location']

    datadir = options.get('mysql_datadir')
    if not os.path.exists(datadir):
      os.mkdir(datadir)

    ibdata1 = os.path.join(datadir, 'ibdata1')
    mysql_software_bin = options.get("mysql_software_bin")
    if not os.path.exists(ibdata1):
      command = '%s/mysql_install_db --datadir=%s' % (mysql_software_bin, datadir)
      print command
      subprocess.call(command, shell=True)

    self.install_script('mysql')
    self.install_script("mysqld_safe")
    self.install_script("mysqladmin")
    self.install_script("mysqldump")

    if options.get("mysql_auto_start").lower() == "true":
      mysql_bin_folder = options.get("mysql_bin_folder")
      command = '%s/mysqld_safe &' % (mysql_bin_folder)
      subprocess.call(command, shell=True)
      sleep(20)

    return location

  update = install
